==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/BubbleSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SizeScaleDescriptionMetadata } from "./SizeScaleDescriptionMetadata";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { BubbleSeriesDescription } from "./BubbleSeriesDescription";
/**
 * @hidden
 */
export let BubbleSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class BubbleSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (BubbleSeriesDescriptionMetadata.a == null) {
                BubbleSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BubbleSeriesDescriptionMetadata.c(BubbleSeriesDescriptionMetadata.a);
            }
            if (a.k(BubbleSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(BubbleSeriesDescriptionMetadata.a);
            SizeScaleDescriptionMetadata.d(a);
            BrushScaleDescriptionMetadata.d(a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
            a.item("RadiusMemberPath", "String");
            a.item("RadiusScale", "ExportedType:SizeScale");
            a.item("RadiusScale@mustSetInCode", "WebComponents;Blazor;React;Angular");
            a.item("LabelMemberPath", "String");
            a.item("FillMemberPath", "String");
            a.item("FillScale", "ExportedType:BrushScale");
            a.item("FillScale@mustSetInCode", "WebComponents;Blazor;React;Angular");
            a.item("FillScaleUseGlobalValues", "Boolean");
            a.item("MarkerOutlineUsesFillScale", "Boolean");
            a.item("MarkerOutlineBrightness", "Number:double");
            a.item("MarkerBrushBrightness", "Number:double");
            a.item("RadiusScaleUseGlobalValues", "Boolean");
            a.item("RadiusMemberAsLegendLabel", "String");
            a.item("FillMemberAsLegendLabel", "String");
            a.item("RadiusMemberAsLegendUnit", "String");
            a.item("FillMemberAsLegendUnit", "String");
        }
        static d(a) {
            BubbleSeriesDescriptionMetadata.b(a);
            a.ad("BubbleSeries", () => new BubbleSeriesDescription());
            a.ac("BubbleSeries", BubbleSeriesDescriptionMetadata.a);
        }
    }
    BubbleSeriesDescriptionMetadata.$t = markType(BubbleSeriesDescriptionMetadata, 'BubbleSeriesDescriptionMetadata');
    BubbleSeriesDescriptionMetadata.a = null;
    return BubbleSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/BubbleSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SizeScaleDescriptionMetadata } from "./SizeScaleDescriptionMetadata";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { BubbleSeriesDescription } from "./BubbleSeriesDescription";
/**
 * @hidden
 */
export let BubbleSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class BubbleSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (BubbleSeriesDescriptionMetadata.a == null) {
                BubbleSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BubbleSeriesDescriptionMetadata.c(BubbleSeriesDescriptionMetadata.a);
            }
            if (a.k(BubbleSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(BubbleSeriesDescriptionMetadata.a);
            SizeScaleDescriptionMetadata.d(a);
            BrushScaleDescriptionMetadata.d(a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
            a.item("RadiusMemberPath", "String");
            a.item("RadiusScale", "ExportedType:SizeScale");
            a.item("RadiusScale@mustSetInCode", "WebComponents;Blazor;React;Angular");
            a.item("LabelMemberPath", "String");
            a.item("FillMemberPath", "String");
            a.item("FillScale", "ExportedType:BrushScale");
            a.item("FillScale@mustSetInCode", "WebComponents;Blazor;React;Angular");
            a.item("FillScaleUseGlobalValues", "Boolean");
            a.item("MarkerOutlineUsesFillScale", "Boolean");
            a.item("MarkerOutlineBrightness", "Number:double");
            a.item("MarkerBrushBrightness", "Number:double");
            a.item("RadiusScaleUseGlobalValues", "Boolean");
            a.item("RadiusMemberAsLegendLabel", "String");
            a.item("FillMemberAsLegendLabel", "String");
            a.item("RadiusMemberAsLegendUnit", "String");
            a.item("FillMemberAsLegendUnit", "String");
        }
        static d(a) {
            BubbleSeriesDescriptionMetadata.b(a);
            a.ae("BubbleSeries", () => new BubbleSeriesDescription());
            a.ad("BubbleSeries", BubbleSeriesDescriptionMetadata.a);
        }
    }
    BubbleSeriesDescriptionMetadata.$t = markType(BubbleSeriesDescriptionMetadata, 'BubbleSeriesDescriptionMetadata');
    BubbleSeriesDescriptionMetadata.a = null;
    return BubbleSeriesDescriptionMetadata;
})();
